# Balanced K-Means clustering in PyTorch

Balanced K-Means clustering in Pytorch with strong GPU acceleration.

**Disclaimer:** This project is heavily inspired by the project [kmeans_pytorch](https://github.com/subhadarship/kmeans_pytorch). Each part of the original implementation is combined with the appropriate attribution.


# Credits
This implementation extends the package `kmeans_pytorch` which contains the
implementation of the original Lloyd's K-means algorithm in Pytorch. You can check (and star!)
the original package [here](https://github.com/subhadarship/kmeans_pytorch).


For licensing of this project, please refer to this repo as well as the `kmeans_pytorch` repo.
